AudioChunk

data.datamodel.AudioChunk()

Segment of audio, usually created by Voice Activity Detection (VAD).

Attributes

Name Type Description
start float Start time of the chunk in seconds.
end float End time of the chunk in seconds.
text (str, optional) Optional text transcription for the chunk.
duration (float, optional) Duration of the chunk in seconds.
audio_frames (int, optional) Number of audio frames a chunk spans.
num_logits (int, optional) Number of model output logits for the chunk.
language (str, optional) Language code for the chunk.
language_prob (float, optional) Probability/confidence of the detected language.
id (str or int, optional) Optional unique identifier for the chunk.