AudioMetadata

data.datamodel.AudioMetadata()

Data model for the metadata of an audio file.

Attributes

Name Type Description
audio_path str Path to the audio file.
sample_rate int Sample rate of the audio file.
duration float Duration of the audio file in seconds.
id (str or int, optional) Optional unique identifier for the document.
speeches (list[SpeechSegment], optional) List of speech segments in the audio.
metadata (dict, optional) Optional extra metadata.