WordSegment

data.datamodel.WordSegment()

Word-level alignment data.

Attributes

Name Type Description
text str The aligned word’s text.
start float Start time of the word in seconds.
end float End time of the word in seconds.
score (float, optional) Optional confidence score for the word alignment.